@@ -3,10 +3,10 @@ package PDF::Builder::Basic::PDF::Filter::FlateDecode;
 use base 'PDF::Builder::Basic::PDF::Filter';
 
 use strict;
-no warnings qw[ deprecated recursion uninitialized ];
+use warnings;
 
-our $VERSION = '3.015'; # VERSION
-my $LAST_UPDATE = '3.010'; # manually update whenever code is changed
+our $VERSION = '3.016'; # VERSION
+my $LAST_UPDATE = '3.016'; # manually update whenever code is changed
 
 use POSIX qw(ceil floor);
 
@@ -18,8 +18,7 @@ PDF::Builder::Basic::PDF::Filter::FlateDecode - compress and uncompress stream f
 
 =cut
 
-BEGIN
-{
+BEGIN {
     eval { require Compress::Zlib };
     $havezlib = !$@;
 }
@@ -33,7 +32,7 @@ sub new {
     };
 
     $self->{'outfilt'} = Compress::Zlib::deflateInit(
-        -Level => 9,
+        -Level   => 9,
         -Bufsize => 32768,
     );
     $self->{'infilt'} = Compress::Zlib::inflateInit();
@@ -41,48 +40,45 @@ sub new {
 }
 
 sub outfilt {
-    my ($self, $str, $isend) = @_;
+    my ($self, $str, $is_end) = @_;
 
-    my ($res);
-
-    $res = $self->{'outfilt'}->deflate($str);
-    $res .= $self->{'outfilt'}->flush() if $isend;
-    return $res;
+    my $result = $self->{'outfilt'}->deflate($str);
+    $result .= $self->{'outfilt'}->flush() if $is_end;
+    return $result;
 }
 
 sub infilt {
     my ($self, $dat, $last) = @_;
 
-    my ($res, $status) = $self->{'infilt'}->inflate("$dat");
+    my ($result, $status) = $self->{'infilt'}->inflate("$dat");
 
     if ($self->{'DecodeParms'} and $self->{'DecodeParms'}->{'Predictor'}) {
         my $predictor = $self->{'DecodeParms'}->{'Predictor'}->val();
         if ($predictor == 2) {
             die "The TIFF predictor logic has not been implemented";
         } elsif ($predictor >= 10 and $predictor <= 15) {
-            $res = $self->_depredict_png($res);
+            $result = $self->_depredict_png($result);
         } else {
             die "Invalid predictor: $predictor";
         }
     }
 
-    return $res;
+    return $result;
 }
 
 sub _depredict_png {
     my ($self, $stream) = @_;
-
     my $param  = $self->{'DecodeParms'};
 
     my $prev = '';
     $stream = $self->{'_depredict_next'} . $stream if defined $self->{'_depredict_next'};
     $prev   = $self->{'_depredict_prev'}           if defined $self->{'_depredict_prev'};
 
-    my $alpha   = $param->{'Alpha'}? $param->{'Alpha'}->val(): 0;
+    my $alpha   = $param->{'Alpha'}           ? $param->{'Alpha'}->val(): 0;
     my $bpc     = $param->{'BitsPerComponent'}? $param->{'BitsPerComponent'}->val(): 8;
-    my $colors  = $param->{'Colors'}? $param->{'Colors'}->val(): 1;
-    my $columns = $param->{'Columns'}? $param->{'Columns'}->val(): 1;
-    my $height  = $param->{'Height'}? $param->{'Height'}->val(): 0;
+    my $colors  = $param->{'Colors'}          ? $param->{'Colors'}->val(): 1;
+    my $columns = $param->{'Columns'}         ? $param->{'Columns'}->val(): 1;
+    my $height  = $param->{'Height'}          ? $param->{'Height'}->val(): 0;
 
     my $comp     = $colors + $alpha;
     my $bpp      = ceil($bpc * $comp / 8);
@@ -91,12 +87,10 @@ sub _depredict_png {
     my $clearstream = '';
     my $lastrow = ($height || int(length($stream) / $scanline)) - 1;
     foreach my $n (0 .. $lastrow) {
-        # print STDERR "line $n:";
         my $line = substr($stream, $n * $scanline, $scanline);
         my $filter = vec($line, 0, 8);
         my $clear = '';
         $line = substr($line, 1);
-        # print STDERR " filter=$filter ";
         if      ($filter == 0) {
             $clear = $line;
         } elsif ($filter == 1) {
@@ -121,9 +115,7 @@ sub _depredict_png {
         $prev = $clear;
         foreach my $x (0 .. ($columns * $comp) - 1) {
             vec($clearstream, ($n * $columns * $comp) + $x, $bpc) = vec($clear, $x, $bpc);
-            # print STDERR "" . vec($clear, $x, $bpc) . ",";
         }
-        # print STDERR "\n";
     }
     $self->{'_depredict_next'} = substr($stream, ($lastrow + 1) * $scanline);
     $self->{'_depredict_prev'} = $prev;
